Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(629)

Unified Diff: pkg/compiler/lib/src/types/map_type_mask.dart

Issue 2622583004: Use entities in all masks. (Closed)
Patch Set: Update comment. Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/compiler/lib/src/types/map_type_mask.dart
diff --git a/pkg/compiler/lib/src/types/map_type_mask.dart b/pkg/compiler/lib/src/types/map_type_mask.dart
index 230db17d0f10de5ab805758a282fc2f5fd16195c..148fdbf58d7d051156eff4fa44bfc2b53b591cd1 100644
--- a/pkg/compiler/lib/src/types/map_type_mask.dart
+++ b/pkg/compiler/lib/src/types/map_type_mask.dart
@@ -15,8 +15,8 @@ class MapTypeMask extends ForwardingTypeMask {
// The [Node] where this type mask was created.
final Node allocationNode;
- // The [Element] where this type mask was created.
- final Element allocationElement;
+ // The [Entity] where this type mask was created.
+ final Entity allocationElement;
// The value type of this map.
final TypeMask valueType;

Powered by Google App Engine
This is Rietveld 408576698